/* -*- mode: c++; indent-tabs-mode: nil -*- */
/** @file QC_UUID.qpp UUID class definition

  uuid Qore module

  Copyright (C) 2010 - 2012 David Nichols

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "uuid-module.h"
/* Qore class Qore::UUID::UUID */

qore_classid_t CID_UUID;
QoreClass* QC_UUID;

// nothing UUID::clear(){}
static QoreValue UUID_clear(QoreObject* self, QoreUUID* uuid, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 142 "/home/abuild/rpmbuild/BUILD/module-uuid-1.4.1/src/QC_UUID.qpp"
    uuid->clear();
    return QoreValue();
}

// int UUID::compare(UUID other){}
static QoreValue UUID_compare_C4UUID(QoreObject* self, QoreUUID* uuid, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    HARD_QORE_VALUE_OBJ_DATA(other, QoreUUID, args, 0, CID_UUID, "UUID::compare()", "UUID", xsink);
    if (*xsink)
        return 0;
# 173 "/home/abuild/rpmbuild/BUILD/module-uuid-1.4.1/src/QC_UUID.qpp"
    SimpleRefHolder<QoreUUID> holder(other);

   return uuid->compare(*other);
}

// UUID::constructor(int flags = Qore::UUID::None) {}
static void UUID_constructor_Vi(QoreObject* self, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 flags = HARD_QORE_VALUE_INT(args, 0);
# 79 "/home/abuild/rpmbuild/BUILD/module-uuid-1.4.1/src/QC_UUID.qpp"
self->setPrivate(CID_UUID, new QoreUUID((int)flags));
}

// UUID::constructor(string uuid_str) {}
static void UUID_constructor_Vs(QoreObject* self, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    const QoreStringNode* uuid_str = HARD_QORE_VALUE_STRING(args, 0);
# 94 "/home/abuild/rpmbuild/BUILD/module-uuid-1.4.1/src/QC_UUID.qpp"
SimpleRefHolder<QoreUUID> uuid(new QoreUUID(*uuid_str, xsink));
   if (*xsink)
      return;
 
   self->setPrivate(CID_UUID, uuid.release());
}

// UUID::copy() {}
static void UUID_copy(QoreObject* self, QoreObject* old, QoreUUID* uuid, ExceptionSink* xsink) {
# 109 "/home/abuild/rpmbuild/BUILD/module-uuid-1.4.1/src/QC_UUID.qpp"
self->setPrivate(CID_UUID, new QoreUUID(*uuid));
}

// nothing UUID::generate(int flags = Qore::UUID::None){}
static QoreValue UUID_generate_Vi(QoreObject* self, QoreUUID* uuid, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 flags = HARD_QORE_VALUE_INT(args, 0);
# 159 "/home/abuild/rpmbuild/BUILD/module-uuid-1.4.1/src/QC_UUID.qpp"
    uuid->generate((int)flags);
    return QoreValue();
}

// bool UUID::isNull(){}
static QoreValue UUID_isNull(QoreObject* self, QoreUUID* uuid, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 135 "/home/abuild/rpmbuild/BUILD/module-uuid-1.4.1/src/QC_UUID.qpp"
    return uuid->isNull();
}

// nothing UUID::set(string uuid_str){}
static QoreValue UUID_set_Vs(QoreObject* self, QoreUUID* uuid, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    const QoreStringNode* uuid_str = HARD_QORE_VALUE_STRING(args, 0);
# 189 "/home/abuild/rpmbuild/BUILD/module-uuid-1.4.1/src/QC_UUID.qpp"
    uuid->set(*uuid_str, xsink);
    return QoreValue();
}

// string UUID::toString(int flag = Qore::UUID::LowerCase){}
static QoreValue UUID_toString_Vi(QoreObject* self, QoreUUID* uuid, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 flag = HARD_QORE_VALUE_INT(args, 0);
# 123 "/home/abuild/rpmbuild/BUILD/module-uuid-1.4.1/src/QC_UUID.qpp"
    return uuid->toString((int)flag);
}

// static string UUID::get(int str_flag = Qore::UUID::LowerCase, int gen_flags = Qore::UUID::None){}
static QoreValue static_UUID_get_ViVi(const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 str_flag = HARD_QORE_VALUE_INT(args, 0);
    int64 gen_flags = HARD_QORE_VALUE_INT(args, 1);
# 199 "/home/abuild/rpmbuild/BUILD/module-uuid-1.4.1/src/QC_UUID.qpp"
return QoreUUID::get((int)str_flag, (int)gen_flags);
}

DLLLOCAL void preinitUUIDClass() {
    QC_UUID = new QoreClass("UUID", "::Qore::UUID::UUID", QDOM_DEFAULT);
    CID_UUID = QC_UUID->getID();
    QC_UUID->setSystem();
}

DLLLOCAL QoreClass* initUUIDClass(QoreNamespace& ns) {
    if (!QC_UUID)
        preinitUUIDClass();

    // nothing UUID::clear(){}
    QC_UUID->addMethod("clear", (q_method_n_t)UUID_clear, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo);

    // int UUID::compare(UUID other){}
    QC_UUID->addMethod("compare", (q_method_n_t)UUID_compare_C4UUID, Public, QCF_CONSTANT, QDOM_DEFAULT, bigIntTypeInfo, 1, QC_UUID->getTypeInfo(), QORE_PARAM_NO_ARG, "other");

    // UUID::constructor(int flags = Qore::UUID::None) {}
    QC_UUID->addConstructor(UUID_constructor_Vi, Public, QCF_NO_FLAGS, QDOM_DEFAULT, 1, bigIntTypeInfo, QoreSimpleValue().assign((int64)QUF_NONE), "flags");

    // UUID::constructor(string uuid_str) {}
    QC_UUID->addConstructor(UUID_constructor_Vs, Public, QCF_NO_FLAGS, QDOM_DEFAULT, 1, stringTypeInfo, QORE_PARAM_NO_ARG, "uuid_str");

    // UUID::copy() {}
    QC_UUID->setCopy((q_copy_t)UUID_copy);

    // nothing UUID::generate(int flags = Qore::UUID::None){}
    QC_UUID->addMethod("generate", (q_method_n_t)UUID_generate_Vi, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, bigIntTypeInfo, QoreSimpleValue().assign((int64)QUF_NONE), "flags");

    // bool UUID::isNull(){}
    QC_UUID->addMethod("isNull", (q_method_n_t)UUID_isNull, Public, QCF_CONSTANT, QDOM_DEFAULT, boolTypeInfo);

    // nothing UUID::set(string uuid_str){}
    QC_UUID->addMethod("set", (q_method_n_t)UUID_set_Vs, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, stringTypeInfo, QORE_PARAM_NO_ARG, "uuid_str");

    // string UUID::toString(int flag = Qore::UUID::LowerCase){}
    QC_UUID->addMethod("toString", (q_method_n_t)UUID_toString_Vi, Public, QCF_CONSTANT, QDOM_DEFAULT, stringTypeInfo, 1, bigIntTypeInfo, QoreSimpleValue().assign((int64)QUF_LOWER_CASE), "flag");

    // static string UUID::get(int str_flag = Qore::UUID::LowerCase, int gen_flags = Qore::UUID::None){}
    QC_UUID->addStaticMethod("get", (q_func_n_t)static_UUID_get_ViVi, Public, QCF_CONSTANT, QDOM_DEFAULT, stringTypeInfo, 2, bigIntTypeInfo, QoreSimpleValue().assign((int64)QUF_LOWER_CASE), "str_flag", bigIntTypeInfo, QoreSimpleValue().assign((int64)QUF_NONE), "gen_flags");
# 26 "/home/abuild/rpmbuild/BUILD/module-uuid-1.4.1/src/QC_UUID.qpp"
# 33 "/home/abuild/rpmbuild/BUILD/module-uuid-1.4.1/src/QC_UUID.qpp"
# 36 "/home/abuild/rpmbuild/BUILD/module-uuid-1.4.1/src/QC_UUID.qpp"
# 39 "/home/abuild/rpmbuild/BUILD/module-uuid-1.4.1/src/QC_UUID.qpp"
    ns.addConstant("Empty", ((int64)QUF_EMPTY));
    ns.addConstant("HAVE_UNPARSE_CASE", true);
    ns.addConstant("None", ((int64)QUF_NONE));
    ns.addConstant("Random", ((int64)QUF_RANDOM));
    ns.addConstant("Time", ((int64)QUF_TIME));
# 46 "/home/abuild/rpmbuild/BUILD/module-uuid-1.4.1/src/QC_UUID.qpp"
    ns.addConstant("LowerCase", ((int64)QUF_LOWER_CASE));
    ns.addConstant("UpperCase", ((int64)QUF_UPPER_CASE));

    return QC_UUID;
}
